bbprep.ReorientC1Panel
======================

.. currentmodule:: bbprep

.. autoclass:: ReorientC1Panel
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ReorientC1Panel.modify
   
   

   
   
   